import React, { Suspense } from 'react';
import SectionAnimator from '../animations/SectionAnimator';

// Section Components critiques (above the fold)
import Hero from '../sections/Hero';
import HowItWorksSection from '../sections/HowItWorksSection';
import AppShowcase from '../sections/AppShowcase';

// Code splitting : sections non-critiques (below the fold) chargées à la demande
const Testimonials = React.lazy(() => import('../sections/Testimonials'));
const Contact = React.lazy(() => import('../sections/Contact'));
const TravelerSection = React.lazy(() => import('../sections/TravelerSection'));
const SecuritySection = React.lazy(() => import('../sections/SecuritySection'));
const FAQSection = React.lazy(() => import('../sections/FAQSection'));
const WhyUpackuSection = React.lazy(() => import('../sections/WhyUpackuSection'));
const SavingsSimulatorSection = React.lazy(() => import('../sections/SavingsSimulatorSection'));
const HelpCenterSection = React.lazy(() => import('../sections/HelpCenterSection'));
const PolicySection = React.lazy(() => import('../sections/PolicySection'));

// Composant fallback pour le chargement des sections
const SectionLoadingFallback = () => (
  <div className="px-4 py-20 w-full flex justify-center items-center min-h-[300px]">
    <div className="animate-pulse flex flex-col items-center">
      <div className="rounded-md bg-gray-300 dark:bg-gray-700 h-8 w-64 mb-8"></div>
      <div className="rounded-md bg-gray-300 dark:bg-gray-700 h-4 w-3/4 mb-3"></div>
      <div className="rounded-md bg-gray-300 dark:bg-gray-700 h-4 w-1/2 mb-3"></div>
    </div>
  </div>
);

/**
 * Page d'accueil principale avec toutes les sections
 */
const HomePage: React.FC = () => {
  return (
    <main className="relative z-10 pt-6 sm:pt-8 md:pt-10 space-y-0">
      {/* Section 1: Hero - Vision globale d'Upacku avec connectWorld */}
      <section id="hero" className="mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="connectWorld" 
          delay={0.4}
          lineCount={15}
          className="mb-0 sm:mb-0 md:mb-0"
        > 
          <Hero />
        </SectionAnimator>
      </section>
      
      {/* Section 2: Comment ça marche */}
      <section id="process" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleScrollZoomFade" 
          delay={0.1}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        > 
          <HowItWorksSection />
        </SectionAnimator>
      </section>
        {/* Section 3: L'application en action - Essence de connectivité */}
      <section id="app" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="connectWorld" 
          delay={0}
          duration={0.4}
          lineCount={10}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <AppShowcase />
        </SectionAnimator>
      </section>
      
      {/* Section 4: Pourquoi c'est différent */}
      <section id="benefits" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleFadeInUp" 
          delay={0.2}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        > 
          <Suspense fallback={<SectionLoadingFallback />}>
            <WhyUpackuSection />
          </Suspense>
        </SectionAnimator>
      </section>
      
      {/* Section 5: Vous voyagez ? Gagnez de l'argent ! - Essence des voyageurs */}
      <section id="traveler" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="connectWorld" 
          delay={0.1}
          lineCount={12}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        > 
          <Suspense fallback={<SectionLoadingFallback />}>
            <TravelerSection />
          </Suspense>
        </SectionAnimator>
      </section>
      
      {/* Section 6: Security */}
      <section id="security" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleScrollZoomFade" 
          delay={0.2}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <SecuritySection />
          </Suspense>
        </SectionAnimator>
      </section>
        {/* Section 7: Témoignages */}
      <section id="testimonials" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleFadeInUp" 
          delay={0}
          duration={0.4}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        > 
          <Suspense fallback={<SectionLoadingFallback />}>
            <Testimonials />
          </Suspense>
        </SectionAnimator>
      </section>
      
      {/* Section 8: Simulateur d'économies */}
      <section id="simulator" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleScrollZoomFade" 
          delay={0.1}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <SavingsSimulatorSection />
          </Suspense>
        </SectionAnimator>
      </section>
      
      {/* Section 9: FAQ */}
      <section id="faq" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleScrollZoomFade" 
          delay={0.2}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <FAQSection />
          </Suspense>
        </SectionAnimator>
      </section>
        {/* Section 10: Centre d'aide */}
      <section id="help" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleFadeInUp" 
          delay={0}
          duration={0.4}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <HelpCenterSection />
          </Suspense>
        </SectionAnimator>
      </section>
      
      {/* Section 11: Politique et conditions */}
      <section id="policy" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="appleScrollZoomFade" 
          delay={0.1}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <PolicySection />
          </Suspense>
        </SectionAnimator>
      </section>      {/* Section 12: Contact & newsletter - Connexion finale */}
      <section id="contact" className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0">
        <SectionAnimator 
          animationType="connectWorld" 
          delay={0}
          duration={0.4}
          lineCount={8}
          className="mt-0 sm:mt-0 md:mt-0 mb-0 sm:mb-0 md:mb-0"
        >
          <Suspense fallback={<SectionLoadingFallback />}>
            <Contact />
          </Suspense>
        </SectionAnimator>
      </section>
    </main>
  );
};

export default HomePage;
